@@ -280,8 +280,147 @@ Ext.define('MP.data.MetaData', {
                 column.renderer = Ext.bind(function(value) {
                     return this[value];
                 }, dict);
+
+                // TODO: factorize the following code with the equivalent in the
+                //       editors() method
+
+                var store;
+
+                if(Ext.isArray(info.dictionary)) {
+                    // Make a copy, so caller may safely alter it
+                    store = [].concat(info.dictionary);
+                } else {
+                    var sortby = 0; // key by default
+                    var d = info.dictionary;
+                    store = [];
+
+                    for(var k in d) {
+                        if(k == '__sort_by__') {
+                            sortby = (d[k] == 'value' ? 1 : 0);
+                        } else {
+                            store.push([k, d[k]]);
+                        }
+                    }
+
+                    store.sort(function(a,b) {
+                        a = a[sortby];
+                        b = b[sortby];
+                        return a<b ? -1 : (a>b ? 1 : 0);
+                    });
+                }
+
+                column.filter = {
+                    xtype: 'combo',
+                    store: store,
+                    triggerAction: 'all',
+                    typeAhead: true,
+                    forceSelection: true,
+                    allowBlank: false,
+                    minChars: 0
+                };
             } else if(info.lookup && info.lookup.url) {
-                column.filter = { type: 'string' };
+                // TODO: factorize the following code with the equivalent in the
+                //       editors() method
+
+                var lup = info.lookup;
+                var idField = lup.idField || 'id';
+                var flds = [idField];
+                var displayField = lup.displayField;
+                var otherFields = lup.otherFields;
+
+                if(displayField) {
+                    flds.push(displayField);
+                }
+                if(otherFields) {
+                    if(!Ext.isArray(otherFields)) {
+                        otherFields = otherFields.split(',');
+                    }
+                    flds = flds.concat(otherFields);
+                }
+
+                var model = Ext.define('MP.data.ImplicitModel-'+Ext.id(), {
+                    extend: 'Ext.data.Model',
+                    fields: flds,
+                    idProperty: idField
+                });
+
+                var remoteFilter = lup.remoteFilter===undefined ? true : lup.remoteFilter;
+                var remoteSort = lup.remoteSort===undefined ? true : lup.remoteSort;
+
+                var lstore = Ext.create('Ext.data.Store', {
+                    model: model,
+                    pageSize: lup.pageSize === undefined ? 999 : lup.pageSize,
+                    autoLoad: !remoteFilter || !remoteSort,
+                    remoteFilter: remoteFilter,
+                    remoteSort: remoteSort,
+                    sorters: lup.sorters,
+                    proxy: {
+                        type: 'ajax',
+                        url: lup.url,
+                        filterParam: 'filters',
+                        reader: {
+                            type: 'json',
+                            root: lup.resultSlot || 'root',
+                            idProperty: idField,
+                            totalProperty: lup.countSlot || 'count'
+                        }
+                    }
+                });
+                lstore.implicitModel = true;
+
+                var listConfig = {};
+
+                if(lup.innerTpl) {
+                    listConfig.getInnerTpl = Ext.bind(function() {
+                        return this.innerTpl;
+                    }, lup);
+                }
+
+                if(lup.pageSize !== undefined) {
+                    listConfig.createPagingToolbar = function() {
+                        return Ext.widget('pagingtoolbar', {
+                            id: this.id + '-paging-toolbar',
+                            pageSize: this.pageSize,
+                            store: this.dataSource,
+                            border: false,
+                            ownerCt: this,
+                            ownerLayout: this.getComponentLayout(),
+                            getPagingItems: function() {
+                                var items;
+
+                                items = Ext.toolbar.Paging.prototype.getPagingItems.call(this);
+
+                                // Keep only the buttons
+                                items = Ext.Array.filter(items, function(i) {
+                                    return i.itemId == 'first' ||
+                                        i.itemId == 'prev' ||
+                                        i.itemId == 'next' ||
+                                        i.itemId == 'last';
+                                });
+
+                                // Force horizontal centering
+                                items.unshift('->');
+                                items.push('->');
+
+                                return items;
+                            }
+                        });
+                    };
+                }
+
+                column.filter = {
+                    xtype: 'combo',
+                    store: lstore,
+                    displayField: displayField || idField,
+                    loadingText: _('Loading...'),
+                    triggerAction: 'all',
+                    typeAhead: true,
+                    forceSelection: true,
+                    allowBlank: false,
+                    minChars: 0,
+                    pageSize: lup.pageSize,
+                    listConfig: listConfig
+                };
             } else if(info.type === 'string') {
                 var password = info.password === true;
 
@@ -435,6 +574,7 @@ Ext.define('MP.data.MetaData', {
                     xtype: 'combo',
                     store: store,
                     triggerAction: 'all',
+                    typeAhead: true,
                     allowBlank: nullable
                 });
             } else if(info.lookup) {
@@ -533,7 +673,7 @@ Ext.define('MP.data.MetaData', {
                         displayField: displayField || idField,
                         loadingText: _('Loading...'),
                         triggerAction: 'all',
-                        lazyRender: true,
+                        typeAhead: true,
                         selectOnFocus: true,
                         allowBlank: nullable,
                         minChars: 3,
