@@ -595,7 +595,9 @@ Ext.define('MP.grid.plugin.FilterBar', {
                 });
             }
 
-            if (me.enableOperators && column.filter.type != 'combo') {
+            if (me.enableOperators
+                && column.filter.type != 'combo'
+                && !column.filter.noOperatorPlugin) {
                 plugins.push({
                     ptype: 'operatorbutton',
                     listeners: {
