@@ -46,7 +46,7 @@ def app_view(request):
 
 @view_config(route_name='scripts', renderer='json')
 def dynamically_loaded_scripts(request):
-    from simplejson import load, loads, dump
+    from json import load, loads, dump
 
     output = request.registry.settings.get('desktop.manifest', None)
     if output is None:
@@ -95,7 +95,7 @@ def catalog_view(request):
     the request's language.
     """
 
-    from simplejson import dumps
+    from json import dumps
 
     locale = request.localizer
     name = request.locale_name
