@@ -254,7 +254,7 @@ def absolutize(paths, prefix_map):
 def main():
     import argparse
     from os.path import splitext
-    from simplejson import load
+    from json import load
 
     parser = argparse.ArgumentParser(description="JS/CSS packer.",
                                      epilog="Minimize and pack all needed"
